@@ -18,6 +18,11 @@ EDM::EDM ( DataFrame< double > & data,
 //----------------------------------------------------------------
 void EDM::Project () {}
 
+//----------------------------------------------------------------
+// Generate : Implemented in sub-class
+//----------------------------------------------------------------
+void EDM::Generate () {}
+
 //----------------------------------------------------------------
 // Set target (library) vector
 //----------------------------------------------------------------
